@@ -9,8 +9,9 @@
 import argparse
 import logging
 import sys
+import warnings
 from gettext import gettext as _
-from typing import List
+from typing import IO, Callable, List, Optional, Type, cast
 
 from . import (
     __REUSE_version__,
@@ -68,6 +69,11 @@ def parser() -> argparse.ArgumentParser:
     parser.add_argument(
         "--debug", action="store_true", help=_("enable debug statements")
     )
+    parser.add_argument(
+        "--suppress-deprecation",
+        action="store_true",
+        help=_("hide deprecation warnings"),
+    )
     parser.add_argument(
         "--include-submodules",
         action="store_true",
@@ -114,6 +120,9 @@ def parser() -> argparse.ArgumentParser:
                 " copyright holders and licenses to add to the headers of the"
                 " given files.\n"
                 "\n"
+                "By using --contributor, you can specify people or entity that"
+                " contributed but are not copyright holder of the given files."
+                "\n"
                 "The first comment is replaced with a new header containing"
                 " the new copyright and licensing information and its former"
                 " copyright and licensing. If you want to keep the first"
@@ -147,7 +156,7 @@ def parser() -> argparse.ArgumentParser:
         "addheader",
         header.add_arguments,
         header.run,
-        help=argparse.SUPPRESS,
+        help=_("deprecated in favor of annotate"),
     )
 
     add_command(
@@ -235,14 +244,14 @@ def parser() -> argparse.ArgumentParser:
 
 
 def add_command(  # pylint: disable=too-many-arguments,redefined-builtin
-    subparsers,
+    subparsers: argparse._SubParsersAction,
     name: str,
-    add_arguments_func,
-    run_func,
-    formatter_class=None,
-    description: str = None,
-    help: str = None,
-    aliases: list = None,
+    add_arguments_func: Callable[[argparse.ArgumentParser], None],
+    run_func: Callable[[argparse.Namespace, Project, IO[str]], int],
+    formatter_class: Optional[Type[argparse.HelpFormatter]] = None,
+    description: Optional[str] = None,
+    help: Optional[str] = None,
+    aliases: Optional[List[str]] = None,
 ) -> None:
     """Add a subparser for a command."""
     if formatter_class is None:
@@ -259,15 +268,18 @@ def add_command(  # pylint: disable=too-many-arguments,redefined-builtin
     subparser.set_defaults(parser=subparser)
 
 
-def main(args: List[str] = None, out=sys.stdout) -> int:
+def main(args: Optional[List[str]] = None, out: IO[str] = sys.stdout) -> int:
     """Main entry function."""
     if args is None:
-        args = sys.argv[1:]
+        args = cast(List[str], sys.argv[1:])
 
     main_parser = parser()
     parsed_args = main_parser.parse_args(args)
 
     setup_logging(level=logging.DEBUG if parsed_args.debug else logging.WARNING)
+    # Show all warnings raised by ourselves.
+    if not parsed_args.suppress_deprecation:
+        warnings.filterwarnings("default", module="reuse")
 
     if parsed_args.version:
         out.write(f"reuse {__version__}\n")
@@ -284,4 +296,4 @@ def main(args: List[str] = None, out=sys.stdout) -> int:
 
 
 if __name__ == "__main__":
-    main()
+    sys.exit(main())
