@@ -18,7 +18,7 @@ import sys
 from inspect import cleandoc
 from io import StringIO
 from pathlib import Path
-from typing import Optional
+from typing import Generator
 from unittest.mock import create_autospec
 
 import pytest
@@ -43,14 +43,21 @@ CWD = Path.cwd()
 TESTS_DIRECTORY = Path(__file__).parent.resolve()
 RESOURCES_DIRECTORY = TESTS_DIRECTORY / "resources"
 
+
 # REUSE-IgnoreStart
 
 
-def pytest_configure():
+def pytest_addoption(parser):
+    """Allows specification of additional commandline options to parse"""
+    parser.addoption("--loglevel", action="store", default="DEBUG")
+
+
+def pytest_configure(config):
     """Called after command line options have been parsed and all plugins and
     initial conftest files been loaded.
     """
-    setup_logging(level=logging.DEBUG)
+    loglevel = config.getoption("loglevel")
+    setup_logging(level=logging.getLevelName(loglevel))
 
 
 def pytest_runtest_setup(item):
@@ -65,7 +72,7 @@ def git_exe() -> str:
     """Run the test with git."""
     if not GIT_EXE:
         pytest.skip("cannot run this test without git")
-    yield GIT_EXE
+    return str(GIT_EXE)
 
 
 @pytest.fixture()
@@ -73,17 +80,22 @@ def hg_exe() -> str:
     """Run the test with mercurial (hg)."""
     if not HG_EXE:
         pytest.skip("cannot run this test without mercurial")
-    yield HG_EXE
+    return str(HG_EXE)
 
 
 @pytest.fixture(params=[True, False])
-def multiprocessing(request, monkeypatch) -> bool:
+def multiprocessing(request, monkeypatch) -> Generator[bool, None, None]:
     """Run the test with or without multiprocessing."""
     if not request.param:
         monkeypatch.delattr(mp, "Pool")
     yield request.param
 
 
+@pytest.fixture(params=[True, False])
+def add_license_concluded(request) -> Generator[bool, None, None]:
+    yield request
+
+
 @pytest.fixture()
 def empty_directory(tmpdir_factory) -> Path:
     """Create a temporary empty directory."""
@@ -117,6 +129,13 @@ def fake_repository(tmpdir_factory) -> Path:
         "SPDX-License-Identifier: LicenseRef-custom",
         encoding="utf-8",
     )
+    (directory / "src/multiple_licenses.rs").write_text(
+        "SPDX-FileCopyrightText: 2022 Jane Doe\n"
+        "SPDX-License-Identifier: GPL-3.0-or-later\n"
+        "SPDX-License-Identifier: Apache-2.0 OR CC0-1.0"
+        " WITH Autoconf-exception-3.0\n",
+        encoding="utf-8",
+    )
 
     os.chdir(directory)
     return directory
@@ -150,16 +169,18 @@ def _repo_contents(
 
 
 @pytest.fixture()
-def git_repository(fake_repository: Path, git_exe: Optional[str]) -> Path:
+def git_repository(fake_repository: Path, git_exe: str) -> Path:
     """Create a git repository with ignored files."""
     os.chdir(fake_repository)
     _repo_contents(fake_repository)
 
+    # TODO: To speed this up, maybe directly write to '.gitconfig' instead.
     subprocess.run([git_exe, "init", str(fake_repository)], check=True)
     subprocess.run([git_exe, "config", "user.name", "Example"], check=True)
     subprocess.run(
         [git_exe, "config", "user.email", "example@example.com"], check=True
     )
+    subprocess.run([git_exe, "config", "commit.gpgSign", "false"], check=True)
 
     subprocess.run([git_exe, "add", str(fake_repository)], check=True)
     subprocess.run(
@@ -176,7 +197,7 @@ def git_repository(fake_repository: Path, git_exe: Optional[str]) -> Path:
 
 
 @pytest.fixture()
-def hg_repository(fake_repository: Path, hg_exe: Optional[str]) -> Path:
+def hg_repository(fake_repository: Path, hg_exe: str) -> Path:
     """Create a mercurial repository with ignored files."""
     os.chdir(fake_repository)
     _repo_contents(
@@ -204,7 +225,7 @@ def hg_repository(fake_repository: Path, hg_exe: Optional[str]) -> Path:
 
 @pytest.fixture()
 def submodule_repository(
-    git_repository: Path, git_exe: Optional[str], tmpdir_factory
+    git_repository: Path, git_exe: str, tmpdir_factory
 ) -> Path:
     """Create a git repository that contains a submodule."""
     header = cleandoc(
@@ -367,4 +388,13 @@ def mock_date_today(monkeypatch):
     monkeypatch.setattr(datetime, "date", date)
 
 
+@pytest.fixture(
+    params=[[], ["John Doe"], ["John Doe", "Alice Doe"]],
+    ids=["None", "John", "John and Alice"],
+)
+def contributors(request):
+    """Provide contributors for SPDX-FileContributor field generation"""
+    yield request.param
+
+
 # REUSE-IgnoreEnd
