@@ -5,16 +5,14 @@
 
 """All tests for reuse.header"""
 
-# pylint: disable=implicit-str-concat-in-sequence
-
 from inspect import cleandoc
 
 import pytest
 
-from reuse import SpdxInfo
-from reuse._comment import CCommentStyle, CommentCreateError
+from reuse import ReuseInfo
+from reuse.comment import CCommentStyle, CommentCreateError
 from reuse.header import (
-    MissingSpdxInfo,
+    MissingReuseInfo,
     add_new_header,
     create_header,
     find_and_replace_header,
@@ -25,9 +23,7 @@ from reuse.header import (
 
 def test_create_header_simple():
     """Create a super simple header."""
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"})
     expected = cleandoc(
         """
         # SPDX-FileCopyrightText: Jane Doe
@@ -36,14 +32,29 @@ def test_create_header_simple():
         """
     )
 
-    assert create_header(spdx_info).strip() == expected
+    assert create_header(info).strip() == expected
+
+
+def test_create_header_simple_with_contributor():
+    """Create a super simple header."""
+    info = ReuseInfo(
+        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}, {"John Doe"}
+    )
+    expected = cleandoc(
+        """
+        # SPDX-FileCopyrightText: Jane Doe
+        # SPDX-FileContributor: John Doe
+        #
+        # SPDX-License-Identifier: GPL-3.0-or-later
+        """
+    )
+
+    assert create_header(info).strip() == expected
 
 
 def test_create_header_template_simple(template_simple):
     """Create a header with a simple template."""
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"})
     expected = cleandoc(
         """
         # Hello, world!
@@ -54,26 +65,20 @@ def test_create_header_template_simple(template_simple):
         """
     )
 
-    assert (
-        create_header(spdx_info, template=template_simple).strip() == expected
-    )
+    assert create_header(info, template=template_simple).strip() == expected
 
 
 def test_create_header_template_no_spdx(template_no_spdx):
-    """Create a header with a template that does not have all SPDX info."""
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}
-    )
+    """Create a header with a template that does not have all REUSE info."""
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"})
 
-    with pytest.raises(MissingSpdxInfo):
-        create_header(spdx_info, template=template_no_spdx)
+    with pytest.raises(MissingReuseInfo):
+        create_header(info, template=template_no_spdx)
 
 
 def test_create_header_template_commented(template_commented):
     """Create a header with an already-commented template."""
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"})
     expected = cleandoc(
         """
         # Hello, world!
@@ -86,7 +91,7 @@ def test_create_header_template_commented(template_commented):
 
     assert (
         create_header(
-            spdx_info,
+            info,
             template=template_commented,
             template_is_commented=True,
             style=CCommentStyle,
@@ -96,10 +101,8 @@ def test_create_header_template_commented(template_commented):
 
 
 def test_create_header_already_contains_spdx():
-    """Create a new header from a header that already contains SPDX info."""
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}
-    )
+    """Create a new header from a header that already contains REUSE info."""
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"})
     existing = cleandoc(
         """
         # SPDX-FileCopyrightText: John Doe
@@ -117,14 +120,12 @@ def test_create_header_already_contains_spdx():
         """
     )
 
-    assert create_header(spdx_info, header=existing).strip() == expected
+    assert create_header(info, header=existing).strip() == expected
 
 
 def test_create_header_existing_is_wrong():
     """If the existing header contains errors, raise a CommentCreateError."""
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"})
     existing = cleandoc(
         """
         # SPDX-FileCopyrightText: John Doe
@@ -134,12 +135,12 @@ def test_create_header_existing_is_wrong():
     )
 
     with pytest.raises(CommentCreateError):
-        create_header(spdx_info, header=existing)
+        create_header(info, header=existing)
 
 
 def test_create_header_old_syntax():
     """Old copyright syntax is preserved when creating a new header."""
-    spdx_info = SpdxInfo({"GPL-3.0-or-later"}, set())
+    info = ReuseInfo({"GPL-3.0-or-later"})
     existing = cleandoc(
         """
         # Copyright John Doe
@@ -153,12 +154,12 @@ def test_create_header_old_syntax():
         """
     )
 
-    assert create_header(spdx_info, header=existing).strip() == expected
+    assert create_header(info, header=existing).strip() == expected
 
 
 def test_create_header_remove_fluff():
-    """Any stuff that isn't SPDX info is removed when using create_header."""
-    spdx_info = SpdxInfo({"GPL-3.0-or-later"}, set())
+    """Any stuff that isn't REUSE info is removed when using create_header."""
+    info = ReuseInfo({"GPL-3.0-or-later"})
     existing = cleandoc(
         """
         # SPDX-FileCopyrightText: John Doe
@@ -176,16 +177,14 @@ def test_create_header_remove_fluff():
         """
     )
 
-    assert create_header(spdx_info, header=existing).strip() == expected
+    assert create_header(info, header=existing).strip() == expected
 
 
 def test_add_new_header_simple():
     """Given text that already contains a header, create a new one, and preserve
     the old one.
     """
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"})
     text = cleandoc(
         """
         # SPDX-FileCopyrightText: John Doe
@@ -208,14 +207,12 @@ def test_add_new_header_simple():
         pass
         """
     )
-    assert add_new_header(text, spdx_info) == expected
+    assert add_new_header(text, info) == expected
 
 
 def test_find_and_replace_no_header():
     """Given text without header, add a header."""
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"})
     text = "pass"
     expected = cleandoc(
         """
@@ -228,15 +225,15 @@ def test_find_and_replace_no_header():
     )
 
     assert (
-        find_and_replace_header(text, spdx_info)
-        == add_new_header(text, spdx_info)
+        find_and_replace_header(text, info)
+        == add_new_header(text, info)
         == expected
     )
 
 
 def test_find_and_replace_verbatim():
     """Replace a header with itself."""
-    spdx_info = SpdxInfo(set(), set())
+    info = ReuseInfo()
     text = cleandoc(
         """
         # SPDX-FileCopyrightText: Jane Doe
@@ -247,16 +244,14 @@ def test_find_and_replace_verbatim():
         """
     )
 
-    assert find_and_replace_header(text, spdx_info) == text
+    assert find_and_replace_header(text, info) == text
 
 
 def test_find_and_replace_newline_before_header():
     """In a scenario where the header is preceded by whitespace, remove the
     preceding whitespace.
     """
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: John Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: John Doe"})
     text = cleandoc(
         """
         # SPDX-FileCopyrightText: Jane Doe
@@ -276,14 +271,12 @@ def test_find_and_replace_newline_before_header():
         """
     )
 
-    assert find_and_replace_header(text, spdx_info) == expected
+    assert find_and_replace_header(text, info) == expected
 
 
 def test_find_and_replace_preserve_preceding():
     """When the SPDX header is in the middle of the file, keep it there."""
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: John Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: John Doe"})
     text = cleandoc(
         """
         # Hello, world!
@@ -312,16 +305,14 @@ def test_find_and_replace_preserve_preceding():
         """
     )
 
-    assert find_and_replace_header(text, spdx_info) == expected
+    assert find_and_replace_header(text, info) == expected
 
 
 def test_find_and_replace_keep_shebang():
     """When encountering a shebang, keep it and put the REUSE header beneath
     it.
     """
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: John Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: John Doe"})
     text = cleandoc(
         """
         #!/usr/bin/env python3
@@ -344,14 +335,14 @@ def test_find_and_replace_keep_shebang():
         """
     )
 
-    assert find_and_replace_header(text, spdx_info) == expected
+    assert find_and_replace_header(text, info) == expected
 
 
 def test_find_and_replace_separate_shebang():
     """When the shebang is part of the same comment as the SPDX comment,
     separate the two.
     """
-    spdx_info = SpdxInfo({"GPL-3.0-or-later"}, set())
+    info = ReuseInfo({"GPL-3.0-or-later"})
     text = cleandoc(
         """
         #!/usr/bin/env python3
@@ -374,12 +365,12 @@ def test_find_and_replace_separate_shebang():
         """
     )
 
-    assert find_and_replace_header(text, spdx_info) == expected
+    assert find_and_replace_header(text, info) == expected
 
 
 def test_find_and_replace_only_shebang():
     """When the file only contains a shebang, keep it at the top of the file."""
-    spdx_info = SpdxInfo({"GPL-3.0-or-later"}, set())
+    info = ReuseInfo({"GPL-3.0-or-later"})
     text = cleandoc(
         """
         #!/usr/bin/env python3
@@ -401,16 +392,14 @@ def test_find_and_replace_only_shebang():
         """
     )
 
-    assert find_and_replace_header(text, spdx_info) == expected
+    assert find_and_replace_header(text, info) == expected
 
 
 def test_find_and_replace_keep_old_comment():
     """When encountering a comment that does not contain copyright and
     licensing information, preserve it below the REUSE header.
     """
-    spdx_info = SpdxInfo(
-        {"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"}
-    )
+    info = ReuseInfo({"GPL-3.0-or-later"}, {"SPDX-FileCopyrightText: Jane Doe"})
     text = cleandoc(
         """
         # Hello, world!
@@ -430,13 +419,13 @@ def test_find_and_replace_keep_old_comment():
         """
     )
 
-    assert find_and_replace_header(text, spdx_info) == expected
+    assert find_and_replace_header(text, info) == expected
 
 
 def test_find_and_replace_preserve_newline():
     """If the file content ends with a newline, don't remove it."""
 
-    spdx_info = SpdxInfo(set(), set())
+    info = ReuseInfo()
     text = (
         cleandoc(
             """
@@ -450,7 +439,7 @@ def test_find_and_replace_preserve_newline():
         + "\n"
     )
 
-    assert find_and_replace_header(text, spdx_info) == text
+    assert find_and_replace_header(text, info) == text
 
 
 # REUSE-IgnoreEnd
