@@ -2,6 +2,7 @@
 # SPDX-FileCopyrightText: 2019 Stefan Bakker <s.bakker777@gmail.com>
 # SPDX-FileCopyrightText: © 2020 Liferay, Inc. <https://liferay.com>
 # SPDX-FileCopyrightText: 2022 Florian Snow <florian@familysnow.net>
+# SPDX-FileCopyrightText: 2022 Pietro Albini <pietro.albini@ferrous-systems.com>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -10,11 +11,12 @@
 # pylint: disable=redefined-outer-name,unused-argument
 
 import errno
+import json
 import os
 import re
 from inspect import cleandoc
 from pathlib import Path
-from typing import Optional
+from typing import Generator, Optional
 from unittest.mock import create_autospec
 from urllib.error import URLError
 
@@ -23,12 +25,15 @@ import pytest
 from reuse import download
 from reuse._main import main
 from reuse._util import GIT_EXE, HG_EXE
+from reuse.report import LINT_VERSION
 
 # REUSE-IgnoreStart
 
 
 @pytest.fixture(params=[True, False])
-def optional_git_exe(request, monkeypatch) -> Optional[str]:
+def optional_git_exe(
+    request, monkeypatch
+) -> Generator[Optional[str], None, None]:
     """Run the test with or without git."""
     exe = GIT_EXE if request.param else ""
     monkeypatch.setattr("reuse.project.GIT_EXE", exe)
@@ -37,7 +42,9 @@ def optional_git_exe(request, monkeypatch) -> Optional[str]:
 
 
 @pytest.fixture(params=[True, False])
-def optional_hg_exe(request, monkeypatch) -> Optional[str]:
+def optional_hg_exe(
+    request, monkeypatch
+) -> Generator[Optional[str], None, None]:
     """Run the test with or without mercurial."""
     exe = HG_EXE if request.param else ""
     monkeypatch.setattr("reuse.project.HG_EXE", exe)
@@ -214,6 +221,29 @@ def test_lint_fail_quiet(fake_repository, stringio):
     assert stringio.getvalue() == ""
 
 
+def test_lint_json(fake_repository, stringio):
+    """Run a failed lint."""
+    result = main(["lint", "--json"], out=stringio)
+    output = json.loads(stringio.getvalue())
+
+    assert result == 0
+    assert output["lint_version"] == LINT_VERSION
+    assert len(output["files"]) == 8
+
+
+def test_lint_json_fail(fake_repository, stringio):
+    """Run a failed lint."""
+    (fake_repository / "foo.py").write_text("foo")
+    result = main(["lint", "--json"], out=stringio)
+    output = json.loads(stringio.getvalue())
+
+    assert result > 0
+    assert output["lint_version"] == LINT_VERSION
+    assert len(output["non_compliant"]["missing_licensing_info"]) == 1
+    assert len(output["non_compliant"]["missing_copyright_info"]) == 1
+    assert len(output["files"]) == 9
+
+
 def test_lint_no_file_extension(fake_repository, stringio):
     """If a license has no file extension, the lint fails."""
     (fake_repository / "LICENSES/CC0-1.0.txt").rename(
@@ -277,10 +307,66 @@ def test_spdx(fake_repository, stringio):
     """Compile to an SPDX document."""
     os.chdir(str(fake_repository))
     result = main(["spdx"], out=stringio)
+    output = stringio.getvalue()
+
+    # Ensure no LicenseConcluded is included without the flag
+    assert "\nLicenseConcluded: NOASSERTION\n" in output
+    assert "\nLicenseConcluded: GPL-3.0-or-later\n" not in output
+    assert "\nCreator: Person: Anonymous ()\n" in output
+    assert "\nCreator: Organization: Anonymous ()\n" in output
 
     # TODO: This test is rubbish.
     assert result == 0
-    assert stringio.getvalue()
+    assert output
+
+
+def test_spdx_creator_info(fake_repository, stringio):
+    """Ensure the --creator-* flags are properly formatted"""
+    os.chdir(str(fake_repository))
+    result = main(
+        [
+            "spdx",
+            "--creator-person=Jane Doe (jane.doe@example.org)",
+            "--creator-organization=FSFE",
+        ],
+        out=stringio,
+    )
+    output = stringio.getvalue()
+
+    assert result == 0
+    assert "\nCreator: Person: Jane Doe (jane.doe@example.org)\n" in output
+    assert "\nCreator: Organization: FSFE ()\n" in output
+
+
+def test_spdx_add_license_concluded(fake_repository, stringio):
+    """Compile to an SPDX document with the LicenseConcluded field."""
+    os.chdir(str(fake_repository))
+    result = main(
+        [
+            "spdx",
+            "--add-license-concluded",
+            "--creator-person=Jane Doe",
+            "--creator-organization=FSFE",
+        ],
+        out=stringio,
+    )
+    output = stringio.getvalue()
+
+    # Ensure no LicenseConcluded is included without the flag
+    assert result == 0
+    assert "\nLicenseConcluded: NOASSERTION\n" not in output
+    assert "\nLicenseConcluded: GPL-3.0-or-later\n" in output
+    assert "\nCreator: Person: Jane Doe ()\n" in output
+    assert "\nCreator: Organization: FSFE ()\n" in output
+
+
+def test_spdx_add_license_concluded_without_creator_info(
+    fake_repository, stringio
+):
+    """Adding LicenseConcluded should require creator information"""
+    os.chdir(str(fake_repository))
+    with pytest.raises(SystemExit):
+        main(["spdx", "--add-license-concluded"], out=stringio)
 
 
 def test_spdx_no_multiprocessing(fake_repository, stringio, multiprocessing):
