@@ -7,9 +7,7 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 """Tests for reuse._main: annotate"""
-
-# pylint: disable=too-many-lines,unused-argument
-
+import logging
 import stat
 from inspect import cleandoc
 
@@ -17,8 +15,12 @@ import pytest
 
 from reuse._main import main
 
+# pylint: disable=too-many-lines,unused-argument
+
+
 # REUSE-IgnoreStart
 
+
 # TODO: Replace this test with a monkeypatched test
 def test_annotate_simple(fake_repository, stringio, mock_date_today):
     """Add a header to a file that does not have one."""
@@ -264,6 +266,75 @@ def test_annotate_shebang_wrong_comment_style(fake_repository, stringio):
     assert simple_file.read_text() == expected
 
 
+def test_annotate_contributors_only(
+    fake_repository, stringio, mock_date_today, contributors
+):
+    """Add a header with only contributor information."""
+
+    if not contributors:
+        pytest.skip("No contributors to add")
+
+    simple_file = fake_repository / "foo.py"
+    simple_file.write_text("pass")
+    content = []
+
+    for contributor in sorted(contributors):
+        content.append(f"# SPDX-FileContributor: {contributor}")
+
+    content += ["", "pass"]
+    expected = cleandoc("\n".join(content))
+
+    args = [
+        "annotate",
+    ]
+    for contributor in contributors:
+        args += ["--contributor", contributor]
+    args += ["foo.py"]
+
+    result = main(
+        args,
+        out=stringio,
+    )
+
+    assert result == 0
+    assert simple_file.read_text() == expected
+
+
+def test_annotate_contributors(
+    fake_repository, stringio, mock_date_today, contributors
+):
+    """Add a header with contributor information."""
+    simple_file = fake_repository / "foo.py"
+    simple_file.write_text("pass")
+    content = ["# SPDX-FileCopyrightText: 2018 Jane Doe"]
+
+    if contributors:
+        for contributor in sorted(contributors):
+            content.append(f"# SPDX-FileContributor: {contributor}")
+
+    content += ["#", "# SPDX-License-Identifier: GPL-3.0-or-later", "", "pass"]
+    expected = cleandoc("\n".join(content))
+
+    args = [
+        "annotate",
+        "--license",
+        "GPL-3.0-or-later",
+        "--copyright",
+        "Jane Doe",
+    ]
+    for contributor in contributors:
+        args += ["--contributor", contributor]
+    args += ["foo.py"]
+
+    result = main(
+        args,
+        out=stringio,
+    )
+
+    assert result == 0
+    assert simple_file.read_text() == expected
+
+
 def test_annotate_specify_style(fake_repository, stringio, mock_date_today):
     """Add a header to a file that does not have one, using a custom style."""
     simple_file = fake_repository / "foo.py"
@@ -420,7 +491,13 @@ def test_annotate_skip_unrecognised_and_style(
     )
 
     assert result == 0
-    assert "no effect" in caplog.text
+    loglevel = logging.getLogger("reuse").level
+    if loglevel > logging.WARNING:
+        pytest.skip(
+            "Test needs LogLevel <= WARNING (e.g. WARNING, INFO, DEBUG)."
+        )
+    else:
+        assert "no effect" in caplog.text
 
 
 def test_annotate_no_copyright_or_license(fake_repository):
@@ -515,7 +592,7 @@ def test_annotate_template_simple_multiple(
 def test_annotate_template_no_spdx(
     fake_repository, stringio, template_no_spdx_source
 ):
-    """Add a header with a template that lacks SPDX info."""
+    """Add a header with a template that lacks REUSE info."""
     simple_file = fake_repository / "foo.py"
     simple_file.write_text("pass")
     template_file = fake_repository / ".reuse/templates/mytemplate.jinja2"
@@ -604,7 +681,6 @@ def test_annotate_template_nonexistant(fake_repository):
 def test_annotate_template_without_extension(
     fake_repository, stringio, mock_date_today, template_simple_source
 ):
-
     """Find the correct header even when not using an extension."""
     simple_file = fake_repository / "foo.py"
     simple_file.write_text("pass")
@@ -1156,7 +1232,7 @@ def test_annotate_line_endings(
 
 
 def test_annotate_skip_existing(fake_repository, stringio, mock_date_today):
-    """When annotate --skip-existing on a file that already contains SPDX info,
+    """When annotate --skip-existing on a file that already contains REUSE info,
     don't write additional information to it.
     """
     for path in ("foo.py", "bar.py"):
